@@ -1,4 +1,4 @@
-## graphics devices in base R, plus those in Cairo, cairoDevice, tikzDevice
+# graphics devices in base R, plus those in Cairo, cairoDevice, tikzDevice
 auto_exts = c(
   bmp = 'bmp', postscript = 'eps', pdf = 'pdf', png = 'png', svg = 'svg',
   jpeg = 'jpeg', pictex = 'tex', tiff = 'tiff', win.metafile = 'wmf',
@@ -33,7 +33,7 @@ check_dev = function(dev) {
       stop('the graphical device', sQuote(dev), 'does not exist (as a function)')
 }
 
-## quartiz devices under Mac
+# quartiz devices under Mac
 quartz_dev = function(type, dpi) {
   force(type); force(dpi)
   function(file, width, height, ...) {
@@ -55,12 +55,12 @@ tikz_dev = function(...) {
   )
 }
 
-## save a recorded plot
+# save a recorded plot
 save_plot = function(plot, name, dev, width, height, ext, dpi, options) {
 
   path = paste(name, ext, sep = '.')
   # when cache=2 and plot file exists, just return the filename
-  if (options$cache == 2 && cache$exists(options$hash)) {
+  if (options$cache == 2 && cache$exists(options$hash, options$cache.lazy)) {
     if (!file.exists(path)) {
       purge_cache(options)
       stop('cannot find ', path, '; the cache has been purged; please re-compile')
@@ -68,7 +68,7 @@ save_plot = function(plot, name, dev, width, height, ext, dpi, options) {
     return(paste(name, if (dev == 'tikz' && options$external) 'pdf' else ext, sep = '.'))
   }
 
-  ## built-in devices
+  # built-in devices
   device = switch(
     dev,
     bmp = function(...) bmp(...,  res = dpi, units = 'in'),
@@ -111,29 +111,36 @@ save_plot = function(plot, name, dev, width, height, ext, dpi, options) {
 
     check_dev(dev)
   )
+  in_base_dir(plot2dev(plot, name, dev, device, path, width, height, options))
+}
 
+plot2dev = function(plot, name, dev, device, path, width, height, options) {
   dargs = get_dargs(options$dev.args, dev)
-  ## re-plot the recorded plot to an off-screen device
+  # re-plot the recorded plot to an off-screen device
   do.call(device, c(list(path, width = width, height = height), dargs))
+  showtext(options$fig.showtext)  # showtext support
   print(plot)
   dev.off()
 
-  ## compile tikz to pdf
+  # compile tikz to pdf
   if (dev == 'tikz' && options$external) {
     unlink(pdf.plot <- paste(name, '.pdf', sep = ''))
     owd = setwd(dirname(path))
     # add old wd to TEXINPUTS (see #188)
     oti = Sys.getenv('TEXINPUTS'); on.exit(Sys.setenv(TEXINPUTS = oti))
     Sys.setenv(TEXINPUTS = paste(owd, oti, sep = ':'))
-    system(paste(switch(getOption('tikzDefaultEngine'),
-                        pdftex = getOption('tikzLatex'),
-                        xetex = getOption('tikzXelatex'),
-                        luatex = getOption('tikzLualatex'),
-                        stop('a LaTeX engine must be specified for tikzDevice',
-                             call. = FALSE)), shQuote(basename(path))),
-           ignore.stdout = TRUE)
+    latex = switch(
+      getOption('tikzDefaultEngine'),
+      pdftex = getOption('tikzLatex'),
+      xetex  = getOption('tikzXelatex'),
+      luatex = getOption('tikzLualatex'),
+      stop('a LaTeX engine must be specified for tikzDevice', call. = FALSE)
+    )
+    system2(latex, shQuote(basename(path)), stdout = NULL)
     setwd(owd)
-    if (file.exists(pdf.plot)) ext = 'pdf' else {
+    if (!file.exists(pdf.plot)) {
+      if (file.exists(log <- paste(name, 'log', sep = '.')))
+        message(paste(readLines(log), collapse = '\n'))
       stop('failed to compile ', path, ' to PDF', call. = FALSE)
     }
     path = pdf.plot
@@ -152,15 +159,15 @@ get_dargs = function(dargs, dev) {
   dargs
 }
 
-## this is mainly for Cairo and cairoDevice
+# this is mainly for Cairo and cairoDevice
 load_device = function(name, package, dpi = NULL) {
   dev = getFromNamespace(name, package)
-  ## dpi is for bitmap devices; units must be inches!
+  # dpi is for bitmap devices; units must be inches!
   if (is.null(dpi)) dev else function(...) dev(..., dpi = dpi, units = 'in')
 }
 
 
-## merge low-level plotting changes
+# merge low-level plotting changes
 merge_low_plot = function(x, idx = sapply(x, is.recordedplot)) {
   idx = which(idx); n = length(idx); m = NULL # store indices that will be removed
   if (n <= 1) return(x)
@@ -174,7 +181,7 @@ merge_low_plot = function(x, idx = sapply(x, is.recordedplot)) {
   if (is.null(m)) x else x[-m]
 }
 
-## compare two recorded plots
+# compare two recorded plots
 is_low_change = function(p1, p2) {
   p1 = p1[[1]]; p2 = p2[[1]]  # real plot info is in [[1]]
   if ((n2 <- length(p2)) < (n1 <- length(p1))) return(FALSE)  # length must increase
@@ -303,3 +310,8 @@ plot_crop = function(x) {
   (if (is_windows()) shell else system)(cmd)
   x
 }
+
+# a wrapper of showtext::showtext.begin()
+showtext = function(show) {
+  if (isTRUE(show)) getFromNamespace('showtext.begin', 'showtext')()
+}
