@@ -19,6 +19,7 @@
 #'   default, numeric columns are right-aligned, and other columns are
 #'   left-aligned; if \code{align = NULL}, the default alignment is used
 #' @param caption the table caption
+#' @param escape escape special characters when producing HTML or LaTeX tables
 #' @param ... other arguments (see examples)
 #' @return A character vector of the table source code. When \code{output =
 #'   TRUE}, the results are also written into the console as a side-effect.
@@ -29,8 +30,10 @@
 #'   \code{pipe_tables} extension is enabled (this is the default behavior for
 #'   Pandoc >= 1.10).
 #'
-#'   When using this function inside a \pkg{knitr} document (e.g. R Markdown or
-#'   R LaTeX), you will need the chunk option \code{results='asis'}.
+#'   When using \code{kable()} as a \emph{top-level} expression, you do not need
+#'   to explicitly \code{print()} it due to R's automatic implicit printing.
+#'   When it is wrapped inside other expressions (such as a \code{\link{for}}
+#'   loop), you must explicitly \code{print(kable(...))}.
 #' @references See
 #'   \url{https://github.com/yihui/knitr-examples/blob/master/091-knitr-table.Rnw}
 #'    for some examples in LaTeX, but they also apply to other document formats.
@@ -63,7 +66,7 @@
 #' # can also set options(knitr.table.format = 'html') so that the output is HTML
 kable = function(
   x, format, digits = getOption('digits'), row.names = NA, col.names = colnames(x),
-  align, caption = NULL, ...
+  align, caption = NULL, escape = TRUE, ...
 ) {
   if (missing(format) || is.null(format)) format = getOption('knitr.table.format')
   if (is.null(format)) format = if (is.null(pandoc_to())) switch(
@@ -101,7 +104,10 @@ kable = function(
   x = format(as.matrix(x), trim = TRUE, justify = 'none')
   colnames(x) = col.names
   attr(x, 'align') = align
-  res = do.call(paste('kable', format, sep = '_'), list(x = x, caption = caption, ...))
+  res = do.call(
+    paste('kable', format, sep = '_'),
+    list(x = x, caption = caption, escape = escape, ...)
+  )
   structure(res, format = format, class = 'knitr_kable')
 }
 
@@ -114,7 +120,7 @@ print.knitr_kable = function(x, ...) {
 #' @export
 knit_print.knitr_kable = function(x, ...) {
   x = paste(c(
-    if (!(attr(x, 'format') %in% c('html', 'latex'))) c('', ''), x, ''
+    if (!(attr(x, 'format') %in% c('html', 'latex'))) c('', ''), x, '\n'
   ), collapse = '\n')
   asis_output(x)
 }
@@ -126,12 +132,14 @@ kable_latex = function(
   bottomrule = if (booktabs) '\\bottomrule' else '\\hline',
   midrule = if (booktabs) '\\midrule' else '\\hline',
   linesep = if (booktabs) c('', '', '', '', '\\addlinespace') else '\\hline',
-  caption = NULL
+  caption = NULL, table.envir = if (!is.null(caption)) 'table', escape = TRUE
 ) {
   if (!is.null(align <- attr(x, 'align', exact = TRUE))) {
     align = paste(align, collapse = vline)
     align = paste('{', align, '}', sep = '')
   }
+  env1 = sprintf('\\begin{%s}\n', table.envir)
+  env2 = sprintf('\n\\end{%s}',   table.envir)
   cap = if (is.null(caption)) '' else sprintf('\n\\caption{%s}', caption)
 
   if (nrow(x) == 0) midrule = ""
@@ -141,20 +149,26 @@ kable_latex = function(
   } else rep('', nrow(x))
   linesep = ifelse(linesep == "", linesep, paste('\n', linesep, sep = ''))
 
+  if (escape) x = escape_latex(x)
+
   paste(c(
+    env1,
     cap,
     sprintf('\n\\begin{%s}', if (longtable) 'longtable' else 'tabular'), align,
     sprintf('\n%s', toprule), '\n',
-    if (!is.null(cn <- colnames(x)))
-      paste(paste(cn, collapse = ' & '), sprintf('\\\\\n%s\n', midrule), sep = ''),
+    if (!is.null(cn <- colnames(x))) {
+      if (escape) cn = escape_latex(cn)
+      paste(paste(cn, collapse = ' & '), sprintf('\\\\\n%s\n', midrule), sep = '')
+    },
     paste(apply(x, 1, paste, collapse = ' & '), sprintf('\\\\%s', linesep),
           sep = '', collapse = '\n'),
     sprintf('\n%s', bottomrule),
-    sprintf('\n\\end{%s}', if (longtable) 'longtable' else 'tabular')
+    sprintf('\n\\end{%s}', if (longtable) 'longtable' else 'tabular'),
+    env2
   ), collapse = '')
 }
 
-kable_html = function(x, table.attr = '', caption = NULL, ...) {
+kable_html = function(x, table.attr = '', caption = NULL, escape = TRUE, ...) {
   table.attr = gsub('^\\s+|\\s+$', '', table.attr)
   # need a space between <table and attributes
   if (nzchar(table.attr)) table.attr = paste('', table.attr)
@@ -162,10 +176,13 @@ kable_html = function(x, table.attr = '', caption = NULL, ...) {
     sprintf(' style="text-align:%s;"', c(l = 'left', c = 'center', r = 'right')[align])
   }
   cap = if (is.null(caption)) '' else sprintf('\n<caption>%s</caption>', caption)
+  if (escape) x = escape_html(x)
   paste(c(
     sprintf('<table%s>%s', table.attr, cap),
-    if (!is.null(cn <- colnames(x)))
-      c(' <thead>', '  <tr>', sprintf('   <th%s> %s </th>', align, cn), '  </tr>', ' </thead>'),
+    if (!is.null(cn <- colnames(x))) {
+      if (escape) cn = escape_html(cn)
+      c(' <thead>', '  <tr>', sprintf('   <th%s> %s </th>', align, cn), '  </tr>', ' </thead>')
+    },
     '<tbody>',
     paste(
       '  <tr>',
